==> kubernetes-model-policy-5.0.2-sources.jar: io/fabric8/kubernetes/api/model/policy/AllowedCSIDriverFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AllowedCSIDriverFluentImpl<A extends AllowedCSIDriverFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AllowedCSIDriverFluent<A> {

    private String name;

    public AllowedCSIDriverFluentImpl() {
    }

    public AllowedCSIDriverFluentImpl(AllowedCSIDriver instance) {
        this.withName(instance.getName()); 
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AllowedCSIDriverFluentImpl that = (AllowedCSIDriverFluentImpl) o;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(name,  super.hashCode());
    }

}

==> kubernetes-model-policy-5.3.1-sources.jar: io/fabric8/kubernetes/api/model/policy/AllowedCSIDriverFluentImpl.java <==
package io.fabric8.kubernetes.api.model.policy;

import java.lang.StringBuffer;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

public class AllowedCSIDriverFluentImpl<A extends AllowedCSIDriverFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements AllowedCSIDriverFluent<A> {

    private String name;

    public AllowedCSIDriverFluentImpl() {
    }

    public AllowedCSIDriverFluentImpl(AllowedCSIDriver instance) {
        this.withName(instance.getName()); 
    }

    public String getName() {
        return this.name;
    }

    public A withName(String name) {
        this.name=name; return (A) this;
    }

    public Boolean hasName() {
        return this.name != null;
    }

    public A withNewName(StringBuilder arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(int[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(char[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(StringBuffer arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(byte[] arg1,int arg2) {
        return (A)withName(new String(arg1, arg2));
    }

    public A withNewName(byte[] arg1) {
        return (A)withName(new String(arg1));
    }

    public A withNewName(char[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3) {
        return (A)withName(new String(arg1, arg2, arg3));
    }

    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4) {
        return (A)withName(new String(arg1, arg2, arg3, arg4));
    }

    public A withNewName(String arg1) {
        return (A)withName(new String(arg1));
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        AllowedCSIDriverFluentImpl that = (AllowedCSIDriverFluentImpl) o;
        if (name != null ? !name.equals(that.name) :that.name != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(name,  super.hashCode());
    }

}
